1.16.0 “Doctor Donkey” — Rucio 1.2 documentation

# 1.16.0 “Doctor Donkey”

## General

### Update Instructions

This feature release requires a database schema update. Please consult the documentation about updating your database schema.

### Features

- Documentation: Add new unique index to oracle schema file #762
- Transfers: Define a proper interface for the rucio transfertool #954

### Enhancements

- Clients: Add client tests and packaging validation for python 2.6, 2,7, 3.4, 3.5, 3.6 in travis #1017
- Core & Internals: Fix permissions for CMS #1005
- Core & Internals: CMS schema is too permissive #1007
- Core & Internals: core package updates #1080
- Core & Internals: Add rucio daemons CLIS as command-Line applications and entry points #992
- Documentation: add documentation build validation in travis #1025
- Documentation: Add release notes to repository #912
- remove unused file from common #1083
- Probes & Alarms: nagios: sync root internal proxies #1032
- Release management: Add python2.7 conditional requirements to core dependencies to support pip py3 installation #1009
- Release management: flake8 package update to 3.5.0 #1012
- Release management: Extend setup.py with dev requirements/dependencies in extra-requires #1020
- Release management: setuptools package update to 39.0.1 #1024
- Testing: Extend travis with matrix expansion to tests in parallel several configurations (py26, 27, 3, mysql, oracle, postgresl, etc ) #1018
- Testing: Add flake8 and pylint python 3 syntax check for rucio (allow_failures mode) #1019
- Testing: add sqlite backend tests to Travis #1022
- Testing: Change pep8 to pycodestyle #1039

### Bugs

- Core & Internals: Adding existing files to archive fails #1051
- Core & Internals: core: rse add protocols does not set third_party_copy #1057
- Transfers: Transfer : verify_checksum is not properly passed to FTS #1040
- Transfers: Transfer : Fix compatible transfers mapping #1060

## Clients

### Features

- Clients: Possibility to pass a timeout for a protocol #27

### Enhancements

- Clients: Clients: configurable transfer_timeout in rucio.cfg #1038
- Clients: package updates #1078
- Clients: Documentation and cleanup of downloadclient and uploadclient #717

## WebUI

### Enhancements

- WebUI: Automatic file transfers for non-WebDAV enabled sites #666